import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.images_model_base_type import ImagesModelBaseType
from ..models.images_model_file_type import ImagesModelFileType
from ..models.images_model_image_type import ImagesModelImageType
from ..models.images_model_rating import ImagesModelRating
from ..models.images_model_secondary_type_type_1 import ImagesModelSecondaryTypeType1
from ..models.images_model_secondary_type_type_2_type_1 import ImagesModelSecondaryTypeType2Type1
from ..models.images_model_secondary_type_type_3_type_1 import ImagesModelSecondaryTypeType3Type1
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.images_model_organization import ImagesModelOrganization


T = TypeVar("T", bound="ImagesModel")


@_attrs_define
class ImagesModel:
    """
    Attributes:
        image_id (Union[Unset, UUID]): The unique identifier of the image record Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, ImagesModelOrganization]): The organization that this images belongs to
        base_type (Union[Unset, ImagesModelBaseType]): The object that this image relates to
            >- `COMPETITION` Competition
            >- `CONFERENCE` Conference
            >- `DIVISION` Division
            >- `ENTITY` Entity
            >- `ENTITYGROUP` Entity Group
            >- `LEAGUE` League
            >- `ORGANIZATION` Organization
            >- `PERSON` Person
            >- `SEASON` Season
            >- `UNIFORM` Uniform
            >- `UNIFORM_ITEM` Uniform Item
             Example: entity.
        base_id (Union[Unset, UUID]): The unique identifier of the object associated with this image's record. If the
            `baseType` is `PERSON` then this would be the value of `personId`. Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        file_type (Union[Unset, ImagesModelFileType]): The type of file
            >- `JPG` jpg
            >- `PNG` png
            >- `SVG` svg
             Example: png.
        image_type (Union[Unset, ImagesModelImageType]): Upload Type
            >- `LOGO` Logo - Not valid for 'PERSON' baseType
            >- `LOGO_ALTERNATE` Logo (alternate) - Not valid for 'PERSON' baseType
            >- `LOGO_BACKGROUND` Stylised logo for background purposes - Not valid for 'PERSON' baseType
            >- `PERSON_HEAD` Head shot (shoulders and head) - Only valid for 'PERSON' baseType
            >- `PERSON_POSE` Person posing - Only valid for 'PERSON' baseType
            >- `PERSON_WAIST` Head shot from the waist up - Only valid for 'PERSON' baseType
            >- `TEAM_PHOTO` Team Photo - Only valid for 'ENTITY' baseType
            >- `UNIFORM` Uniform
            >- `UNIFORM_ITEM` Uniform Item
             Example: LOGO.
        secondary_type (Union[ImagesModelSecondaryTypeType1, ImagesModelSecondaryTypeType2Type1,
            ImagesModelSecondaryTypeType3Type1, None, Unset]): If the image relates to a secondary object. Such as a photo
            of a person in a team, then baseType would be PERSON and secondaryType would be TEAM.
            >- None None
            >- `COMPETITION` Competition
            >- `CONFERENCE` Conference
            >- `DIVISION` Division
            >- `ENTITY` Entity
            >- `ENTITYGROUP` Entity Group
            >- `LEAGUE` League
            >- `SEASON` Season
             Example: entity.
        secondary_id (Union[Unset, UUID]): The unique identifier of the object associated with the secondaryType
            Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        rating (Union[Unset, ImagesModelRating]): The rating given to the quality of the image.  All images are LOW by
            default but are set ad MEDIUM if they are large enough and have transparency.  Images are only marked as HIGH if
            they have been manually reviewed.  You should take your use-case into account when you go to use the image.
            >- `HIGH` High
            >- `LOW` Low
            >- `MEDIUM` Medium
             Example: LOW.
        url (Union[Unset, str]): The URL of the image. See [Images](#section/Introduction/Images) for more information.
        maximum_height (Union[Unset, int]): The maximum height (in pixels) of this image. Example: 200.
        maximum_width (Union[Unset, int]): The maximum width (in pixels) of this image. Example: 200.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    image_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "ImagesModelOrganization"] = UNSET
    base_type: Union[Unset, ImagesModelBaseType] = UNSET
    base_id: Union[Unset, UUID] = UNSET
    file_type: Union[Unset, ImagesModelFileType] = UNSET
    image_type: Union[Unset, ImagesModelImageType] = UNSET
    secondary_type: Union[
        ImagesModelSecondaryTypeType1,
        ImagesModelSecondaryTypeType2Type1,
        ImagesModelSecondaryTypeType3Type1,
        None,
        Unset,
    ] = UNSET
    secondary_id: Union[Unset, UUID] = UNSET
    rating: Union[Unset, ImagesModelRating] = UNSET
    url: Union[Unset, str] = UNSET
    maximum_height: Union[Unset, int] = UNSET
    maximum_width: Union[Unset, int] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        image_id: Union[Unset, str] = UNSET
        if not isinstance(self.image_id, Unset):
            image_id = str(self.image_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        base_type: Union[Unset, str] = UNSET
        if not isinstance(self.base_type, Unset):
            base_type = self.base_type.value

        base_id: Union[Unset, str] = UNSET
        if not isinstance(self.base_id, Unset):
            base_id = str(self.base_id)

        file_type: Union[Unset, str] = UNSET
        if not isinstance(self.file_type, Unset):
            file_type = self.file_type.value

        image_type: Union[Unset, str] = UNSET
        if not isinstance(self.image_type, Unset):
            image_type = self.image_type.value

        secondary_type: Union[None, Unset, str]
        if isinstance(self.secondary_type, Unset):
            secondary_type = UNSET
        elif isinstance(self.secondary_type, ImagesModelSecondaryTypeType1):
            secondary_type = self.secondary_type.value
        elif isinstance(self.secondary_type, ImagesModelSecondaryTypeType2Type1):
            secondary_type = self.secondary_type.value
        elif isinstance(self.secondary_type, ImagesModelSecondaryTypeType3Type1):
            secondary_type = self.secondary_type.value
        else:
            secondary_type = self.secondary_type

        secondary_id: Union[Unset, str] = UNSET
        if not isinstance(self.secondary_id, Unset):
            secondary_id = str(self.secondary_id)

        rating: Union[Unset, str] = UNSET
        if not isinstance(self.rating, Unset):
            rating = self.rating.value

        url = self.url

        maximum_height = self.maximum_height

        maximum_width = self.maximum_width

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if image_id is not UNSET:
            field_dict["imageId"] = image_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if base_type is not UNSET:
            field_dict["baseType"] = base_type
        if base_id is not UNSET:
            field_dict["baseId"] = base_id
        if file_type is not UNSET:
            field_dict["fileType"] = file_type
        if image_type is not UNSET:
            field_dict["imageType"] = image_type
        if secondary_type is not UNSET:
            field_dict["secondaryType"] = secondary_type
        if secondary_id is not UNSET:
            field_dict["secondaryId"] = secondary_id
        if rating is not UNSET:
            field_dict["rating"] = rating
        if url is not UNSET:
            field_dict["url"] = url
        if maximum_height is not UNSET:
            field_dict["maximumHeight"] = maximum_height
        if maximum_width is not UNSET:
            field_dict["maximumWidth"] = maximum_width
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.images_model_organization import ImagesModelOrganization

        d = dict(src_dict)
        _image_id = d.pop("imageId", UNSET)
        image_id: Union[Unset, UUID]
        if isinstance(_image_id, Unset):
            image_id = UNSET
        else:
            image_id = UUID(_image_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, ImagesModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = ImagesModelOrganization.from_dict(_organization)

        _base_type = d.pop("baseType", UNSET)
        base_type: Union[Unset, ImagesModelBaseType]
        if isinstance(_base_type, Unset):
            base_type = UNSET
        else:
            base_type = ImagesModelBaseType(_base_type)

        _base_id = d.pop("baseId", UNSET)
        base_id: Union[Unset, UUID]
        if isinstance(_base_id, Unset):
            base_id = UNSET
        else:
            base_id = UUID(_base_id)

        _file_type = d.pop("fileType", UNSET)
        file_type: Union[Unset, ImagesModelFileType]
        if isinstance(_file_type, Unset):
            file_type = UNSET
        else:
            file_type = ImagesModelFileType(_file_type)

        _image_type = d.pop("imageType", UNSET)
        image_type: Union[Unset, ImagesModelImageType]
        if isinstance(_image_type, Unset):
            image_type = UNSET
        else:
            image_type = ImagesModelImageType(_image_type)

        def _parse_secondary_type(
            data: object,
        ) -> Union[
            ImagesModelSecondaryTypeType1,
            ImagesModelSecondaryTypeType2Type1,
            ImagesModelSecondaryTypeType3Type1,
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                secondary_type_type_1 = ImagesModelSecondaryTypeType1(data)

                return secondary_type_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                secondary_type_type_2_type_1 = ImagesModelSecondaryTypeType2Type1(data)

                return secondary_type_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                secondary_type_type_3_type_1 = ImagesModelSecondaryTypeType3Type1(data)

                return secondary_type_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    ImagesModelSecondaryTypeType1,
                    ImagesModelSecondaryTypeType2Type1,
                    ImagesModelSecondaryTypeType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        secondary_type = _parse_secondary_type(d.pop("secondaryType", UNSET))

        _secondary_id = d.pop("secondaryId", UNSET)
        secondary_id: Union[Unset, UUID]
        if isinstance(_secondary_id, Unset):
            secondary_id = UNSET
        else:
            secondary_id = UUID(_secondary_id)

        _rating = d.pop("rating", UNSET)
        rating: Union[Unset, ImagesModelRating]
        if isinstance(_rating, Unset):
            rating = UNSET
        else:
            rating = ImagesModelRating(_rating)

        url = d.pop("url", UNSET)

        maximum_height = d.pop("maximumHeight", UNSET)

        maximum_width = d.pop("maximumWidth", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        images_model = cls(
            image_id=image_id,
            organization_id=organization_id,
            organization=organization,
            base_type=base_type,
            base_id=base_id,
            file_type=file_type,
            image_type=image_type,
            secondary_type=secondary_type,
            secondary_id=secondary_id,
            rating=rating,
            url=url,
            maximum_height=maximum_height,
            maximum_width=maximum_width,
            updated=updated,
            added=added,
        )

        return images_model



from enum import Enum


class SeasonEntitiesModelRosterStatus(str, Enum):
    APPROVED = "APPROVED"
    PENDING = "PENDING"
    REJECTED = "REJECTED"
    SUBMITTED = "SUBMITTED"
    UNKNOWN = "UNKNOWN"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.standing_configurations_model_standing_configuration_sorting_sort_direction import (
    StandingConfigurationsModelStandingConfigurationSortingSortDirection,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="StandingConfigurationsModelStandingConfigurationSorting")


@_attrs_define
class StandingConfigurationsModelStandingConfigurationSorting:
    """
    Attributes:
        sort_field (Union[Unset, str]): Sort Field
        sort_direction (Union[Unset, StandingConfigurationsModelStandingConfigurationSortingSortDirection]): Sort
            direction
    """

    sort_field: Union[Unset, str] = UNSET
    sort_direction: Union[Unset, StandingConfigurationsModelStandingConfigurationSortingSortDirection] = UNSET

    def to_dict(self) -> dict[str, Any]:
        sort_field = self.sort_field

        sort_direction: Union[Unset, str] = UNSET
        if not isinstance(self.sort_direction, Unset):
            sort_direction = self.sort_direction.value

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if sort_field is not UNSET:
            field_dict["sortField"] = sort_field
        if sort_direction is not UNSET:
            field_dict["sortDirection"] = sort_direction

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        sort_field = d.pop("sortField", UNSET)

        _sort_direction = d.pop("sortDirection", UNSET)
        sort_direction: Union[Unset, StandingConfigurationsModelStandingConfigurationSortingSortDirection]
        if isinstance(_sort_direction, Unset):
            sort_direction = UNSET
        else:
            sort_direction = StandingConfigurationsModelStandingConfigurationSortingSortDirection(_sort_direction)

        standing_configurations_model_standing_configuration_sorting = cls(
            sort_field=sort_field,
            sort_direction=sort_direction,
        )

        return standing_configurations_model_standing_configuration_sorting



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="PersonModelAdditionalNamesType0AdditionalProperty")


@_attrs_define
class PersonModelAdditionalNamesType0AdditionalProperty:
    """The *property name* here can either be `default` (for a non-language specific name) or a two letter (lower-case) ISO
    639-1 language code. eg `fr`, `es`

        Example:
            default

        Attributes:
            display (Union[None, Unset, str]):
            television (Union[None, Unset, str]): The name to be used on television
            scoreboard (Union[None, Unset, str]): The name to be used on the scoreboard
            pronunciation (Union[None, Unset, str]): The description of how to pronounce the name
            boxscore (Union[None, Unset, str]):
            jersey (Union[None, Unset, str]):
            abbreviated (Union[None, Unset, str]):
            given (Union[None, Unset, str]):
            family (Union[None, Unset, str]):
            full (Union[None, Unset, str]):
            known_as (Union[None, Unset, str]):
    """

    display: Union[None, Unset, str] = UNSET
    television: Union[None, Unset, str] = UNSET
    scoreboard: Union[None, Unset, str] = UNSET
    pronunciation: Union[None, Unset, str] = UNSET
    boxscore: Union[None, Unset, str] = UNSET
    jersey: Union[None, Unset, str] = UNSET
    abbreviated: Union[None, Unset, str] = UNSET
    given: Union[None, Unset, str] = UNSET
    family: Union[None, Unset, str] = UNSET
    full: Union[None, Unset, str] = UNSET
    known_as: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        display: Union[None, Unset, str]
        if isinstance(self.display, Unset):
            display = UNSET
        else:
            display = self.display

        television: Union[None, Unset, str]
        if isinstance(self.television, Unset):
            television = UNSET
        else:
            television = self.television

        scoreboard: Union[None, Unset, str]
        if isinstance(self.scoreboard, Unset):
            scoreboard = UNSET
        else:
            scoreboard = self.scoreboard

        pronunciation: Union[None, Unset, str]
        if isinstance(self.pronunciation, Unset):
            pronunciation = UNSET
        else:
            pronunciation = self.pronunciation

        boxscore: Union[None, Unset, str]
        if isinstance(self.boxscore, Unset):
            boxscore = UNSET
        else:
            boxscore = self.boxscore

        jersey: Union[None, Unset, str]
        if isinstance(self.jersey, Unset):
            jersey = UNSET
        else:
            jersey = self.jersey

        abbreviated: Union[None, Unset, str]
        if isinstance(self.abbreviated, Unset):
            abbreviated = UNSET
        else:
            abbreviated = self.abbreviated

        given: Union[None, Unset, str]
        if isinstance(self.given, Unset):
            given = UNSET
        else:
            given = self.given

        family: Union[None, Unset, str]
        if isinstance(self.family, Unset):
            family = UNSET
        else:
            family = self.family

        full: Union[None, Unset, str]
        if isinstance(self.full, Unset):
            full = UNSET
        else:
            full = self.full

        known_as: Union[None, Unset, str]
        if isinstance(self.known_as, Unset):
            known_as = UNSET
        else:
            known_as = self.known_as

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if display is not UNSET:
            field_dict["display"] = display
        if television is not UNSET:
            field_dict["television"] = television
        if scoreboard is not UNSET:
            field_dict["scoreboard"] = scoreboard
        if pronunciation is not UNSET:
            field_dict["pronunciation"] = pronunciation
        if boxscore is not UNSET:
            field_dict["boxscore"] = boxscore
        if jersey is not UNSET:
            field_dict["jersey"] = jersey
        if abbreviated is not UNSET:
            field_dict["abbreviated"] = abbreviated
        if given is not UNSET:
            field_dict["given"] = given
        if family is not UNSET:
            field_dict["family"] = family
        if full is not UNSET:
            field_dict["full"] = full
        if known_as is not UNSET:
            field_dict["knownAs"] = known_as

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_display(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        display = _parse_display(d.pop("display", UNSET))

        def _parse_television(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        television = _parse_television(d.pop("television", UNSET))

        def _parse_scoreboard(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        scoreboard = _parse_scoreboard(d.pop("scoreboard", UNSET))

        def _parse_pronunciation(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        pronunciation = _parse_pronunciation(d.pop("pronunciation", UNSET))

        def _parse_boxscore(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        boxscore = _parse_boxscore(d.pop("boxscore", UNSET))

        def _parse_jersey(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        jersey = _parse_jersey(d.pop("jersey", UNSET))

        def _parse_abbreviated(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        abbreviated = _parse_abbreviated(d.pop("abbreviated", UNSET))

        def _parse_given(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        given = _parse_given(d.pop("given", UNSET))

        def _parse_family(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        family = _parse_family(d.pop("family", UNSET))

        def _parse_full(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        full = _parse_full(d.pop("full", UNSET))

        def _parse_known_as(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        known_as = _parse_known_as(d.pop("knownAs", UNSET))

        person_model_additional_names_type_0_additional_property = cls(
            display=display,
            television=television,
            scoreboard=scoreboard,
            pronunciation=pronunciation,
            boxscore=boxscore,
            jersey=jersey,
            abbreviated=abbreviated,
            given=given,
            family=family,
            full=full,
            known_as=known_as,
        )

        return person_model_additional_names_type_0_additional_property



import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.season_roster_list_by_entity_response_default import SeasonRosterListByEntityResponseDefault
from ...models.season_roster_list_by_entity_season_roster_response import SeasonRosterListByEntitySeasonRosterResponse
from ...models.season_roster_list_by_entity_status import SeasonRosterListByEntityStatus
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    season_id: UUID,
    entity_id: UUID,
    *,
    added: Union[Unset, datetime.datetime] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    status: Union[Unset, SeasonRosterListByEntityStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_added: Union[Unset, str] = UNSET
    if not isinstance(added, Unset):
        json_added = added.isoformat()
    params["added"] = json_added

    params["external"] = external

    params["fields"] = fields

    params["hideNull"] = hide_null

    params["include"] = include

    params["limit"] = limit

    params["offset"] = offset

    json_status: Union[Unset, str] = UNSET
    if not isinstance(status, Unset):
        json_status = status.value

    params["status"] = json_status

    json_updated: Union[Unset, str] = UNSET
    if not isinstance(updated, Unset):
        json_updated = updated.isoformat()
    params["updated"] = json_updated

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/seasons/{season_id}/entities/{entity_id}/roster",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]:
    if response.status_code == 200:
        response_200 = SeasonRosterListByEntitySeasonRosterResponse.from_dict(response.json())

        return response_200

    response_default = SeasonRosterListByEntityResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    season_id: UUID,
    entity_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    status: Union[Unset, SeasonRosterListByEntityStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Response[Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]]:
    """Get the roster for a team for the season

     Return the roster for a team for the season

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        status (Union[Unset, SeasonRosterListByEntityStatus]):  Example: ACTIVE.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        season_id=season_id,
        entity_id=entity_id,
        added=added,
        external=external,
        fields=fields,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        status=status,
        updated=updated,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    season_id: UUID,
    entity_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    status: Union[Unset, SeasonRosterListByEntityStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Optional[Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]]:
    """Get the roster for a team for the season

     Return the roster for a team for the season

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        status (Union[Unset, SeasonRosterListByEntityStatus]):  Example: ACTIVE.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]
    """

    return sync_detailed(
        organization_id=organization_id,
        season_id=season_id,
        entity_id=entity_id,
        client=client,
        added=added,
        external=external,
        fields=fields,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        status=status,
        updated=updated,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    season_id: UUID,
    entity_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    status: Union[Unset, SeasonRosterListByEntityStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Response[Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]]:
    """Get the roster for a team for the season

     Return the roster for a team for the season

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        status (Union[Unset, SeasonRosterListByEntityStatus]):  Example: ACTIVE.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        season_id=season_id,
        entity_id=entity_id,
        added=added,
        external=external,
        fields=fields,
        hide_null=hide_null,
        include=include,
        limit=limit,
        offset=offset,
        status=status,
        updated=updated,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    season_id: UUID,
    entity_id: UUID,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    external: Union[Unset, str] = UNSET,
    fields: Union[Unset, str] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
    status: Union[Unset, SeasonRosterListByEntityStatus] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
) -> Optional[Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]]:
    """Get the roster for a team for the season

     Return the roster for a team for the season

    Args:
        organization_id (str):  Example: b1a23.
        season_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        external (Union[Unset, str]):  Example: entityId,personId.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.
        status (Union[Unset, SeasonRosterListByEntityStatus]):  Example: ACTIVE.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[SeasonRosterListByEntityResponseDefault, SeasonRosterListByEntitySeasonRosterResponse]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            season_id=season_id,
            entity_id=entity_id,
            client=client,
            added=added,
            external=external,
            fields=fields,
            hide_null=hide_null,
            include=include,
            limit=limit,
            offset=offset,
            status=status,
            updated=updated,
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.match_profiles_model_match_profile_configuration import MatchProfilesModelMatchProfileConfiguration
    from ..models.match_profiles_model_organization import MatchProfilesModelOrganization


T = TypeVar("T", bound="MatchProfilesModel")


@_attrs_define
class MatchProfilesModel:
    """
    Attributes:
        profile_id (Union[Unset, UUID]): The unique identifier of the profile Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, MatchProfilesModelOrganization]): The organization that this match profiles belongs
            to
        name (Union[Unset, str]): Name of the match profile
        profile (Union[Unset, MatchProfilesModelMatchProfileConfiguration]): Match Profile Configuration
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        default_profile (Union[Unset, bool]): Is this the default profile for the organization?
    """

    profile_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "MatchProfilesModelOrganization"] = UNSET
    name: Union[Unset, str] = UNSET
    profile: Union[Unset, "MatchProfilesModelMatchProfileConfiguration"] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    default_profile: Union[Unset, bool] = UNSET

    def to_dict(self) -> dict[str, Any]:
        profile_id: Union[Unset, str] = UNSET
        if not isinstance(self.profile_id, Unset):
            profile_id = str(self.profile_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        name = self.name

        profile: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.profile, Unset):
            profile = self.profile.to_dict()

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        default_profile = self.default_profile

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if profile_id is not UNSET:
            field_dict["profileId"] = profile_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if name is not UNSET:
            field_dict["name"] = name
        if profile is not UNSET:
            field_dict["profile"] = profile
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if default_profile is not UNSET:
            field_dict["defaultProfile"] = default_profile

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.match_profiles_model_match_profile_configuration import (
            MatchProfilesModelMatchProfileConfiguration,
        )
        from ..models.match_profiles_model_organization import MatchProfilesModelOrganization

        d = dict(src_dict)
        _profile_id = d.pop("profileId", UNSET)
        profile_id: Union[Unset, UUID]
        if isinstance(_profile_id, Unset):
            profile_id = UNSET
        else:
            profile_id = UUID(_profile_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, MatchProfilesModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = MatchProfilesModelOrganization.from_dict(_organization)

        name = d.pop("name", UNSET)

        _profile = d.pop("profile", UNSET)
        profile: Union[Unset, MatchProfilesModelMatchProfileConfiguration]
        if isinstance(_profile, Unset):
            profile = UNSET
        else:
            profile = MatchProfilesModelMatchProfileConfiguration.from_dict(_profile)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        default_profile = d.pop("defaultProfile", UNSET)

        match_profiles_model = cls(
            profile_id=profile_id,
            organization_id=organization_id,
            organization=organization,
            name=name,
            profile=profile,
            updated=updated,
            added=added,
            external_id=external_id,
            default_profile=default_profile,
        )

        return match_profiles_model



from enum import Enum


class PssListAgeGroup(str, Enum):
    JUNIOR = "JUNIOR"
    MASTERS = "MASTERS"
    SENIOR = "SENIOR"
    UNDER_15 = "UNDER_15"
    UNDER_16 = "UNDER_16"
    UNDER_17 = "UNDER_17"
    UNDER_18 = "UNDER_18"
    UNDER_19 = "UNDER_19"
    UNDER_20 = "UNDER_20"
    UNDER_21 = "UNDER_21"
    UNDER_22 = "UNDER_22"
    UNDER_23 = "UNDER_23"
    YOUTH = "YOUTH"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ErrorListModelReason(str, Enum):
    DELETE_ERROR = "DELETE_ERROR"
    ERROR = "ERROR"
    INVALID_DATA = "INVALID_DATA"
    NOT_AUTHORISED = "NOT_AUTHORISED"
    NOT_FOUND = "NOT_FOUND"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ConductModelConductPenaltyResultPenaltyType(str, Enum):
    FINANCIAL = "FINANCIAL"
    GAMES = "GAMES"
    MONTHS = "MONTHS"
    WEEKS = "WEEKS"
    YEARS = "YEARS"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.standing_adjustment_model_adjustment_field import StandingAdjustmentModelAdjustmentField
from ..models.standing_adjustment_model_adjustment_group import StandingAdjustmentModelAdjustmentGroup
from ..models.standing_adjustment_model_adjustment_type import StandingAdjustmentModelAdjustmentType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.standing_adjustment_model_conference import StandingAdjustmentModelConference
    from ..models.standing_adjustment_model_division import StandingAdjustmentModelDivision
    from ..models.standing_adjustment_model_entity import StandingAdjustmentModelEntity
    from ..models.standing_adjustment_model_organization import StandingAdjustmentModelOrganization
    from ..models.standing_adjustment_model_pool import StandingAdjustmentModelPool
    from ..models.standing_adjustment_model_round import StandingAdjustmentModelRound
    from ..models.standing_adjustment_model_season import StandingAdjustmentModelSeason
    from ..models.standing_adjustment_model_stage import StandingAdjustmentModelStage


T = TypeVar("T", bound="StandingAdjustmentModel")


@_attrs_define
class StandingAdjustmentModel:
    """
    Attributes:
        standing_adjustment_id (Union[Unset, UUID]): The unique identifier of the adjustment Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, StandingAdjustmentModelSeason]): The season linked to this record
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, StandingAdjustmentModelEntity]): The team information
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, StandingAdjustmentModelOrganization]): The organization that this
            ~standing_adjustment~ belongs to
        round_code (Union[None, Unset, str]): A unique code for the round. (Unique for season) Example: RN1.
        round_ (Union[Unset, StandingAdjustmentModelRound]): The ~ROUND~ that is related to this record
        round_number (Union[None, Unset, str]): The number given to the round Example: 1.
        stage_code (Union[None, Unset, str]): A unique code for the stage. (Unique for season) Example: ST1.
        stage (Union[Unset, StandingAdjustmentModelStage]): The stage that is related to this record
        pool_code (Union[None, Unset, str]): A unique code for the pool. (Unique for season) Example: P1.
        pool (Union[Unset, StandingAdjustmentModelPool]): The pool that is related to this record
        division_id (Union[None, UUID, Unset]): The unique identifier of the division Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division (Union[Unset, StandingAdjustmentModelDivision]): The division information
        conference_id (Union[None, UUID, Unset]): The unique identifier of the conference Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        conference (Union[Unset, StandingAdjustmentModelConference]): The conference information
        apply_to_all_standings (Union[Unset, bool]): Apply to all generated standing types ? Example: True.
        adjustment_group (Union[Unset, StandingAdjustmentModelAdjustmentGroup]): Adjustment Group
            >- `IN_CONFERENCE` In Conference
            >- `IN_DIVISION` In Division
            >- `OUT_CONFERENCE` Out Conference
            >- `OUT_DIVISION` Out Division
            >- `OVERALL` Overall
        adjustment_type (Union[Unset, StandingAdjustmentModelAdjustmentType]): Adjustment Type
            >- `ADD_MINUS` Add/Subtract Value
            >- `SET` Set Value
        adjustment_field (Union[Unset, StandingAdjustmentModelAdjustmentField]): Adjustment field to calculate standings
            >- `byes` Byes
            >- `draws` Games Drawn
            >- `drawsAway` Games Drawn (Away)
            >- `drawsHome` Games Drawn (Home)
            >- `forfeitsGiven` Forfeits Given
            >- `forfeitsWonBy` Forfeits Won
            >- `highestScoreAgainst` Highest Score Against
            >- `highestScoreAgainstAway` Highest Score Against (Away)
            >- `highestScoreAgainstHome` Highest Score Against (Home)
            >- `highestScoreFor` Highest Score For
            >- `highestScoreForAway` Highest Score For (Away)
            >- `highestScoreForHome` Highest Score For (Home)
            >- `losses` Games Lost
            >- `lossesAway` Games Lost (Away)
            >- `lossesHome` Games Lost (Home)
            >- `lowestScoreAgainst` Lowest Score Against
            >- `lowestScoreAgainstAway` Lowest Score Against (Away)
            >- `lowestScoreAgainstHome` Lowest Score Against (Home)
            >- `lowestScoreFor` Lowest Score For
            >- `lowestScoreForAway` Lowest Score For (Away)
            >- `lowestScoreForHome` Lowest Score For (Home)
            >- `percentage` For versus Against Percentage
            >- `percentageAway` For versus Against Percentage (Away)
            >- `percentageHome` For versus Against Percentage (Home)
            >- `played` Games Played
            >- `playedAway` Games Played (Away)
            >- `playedHome` Games Played (Home)
            >- `pointDifference` Point Difference
            >- `pointDifferenceAway` Point Difference (Away)
            >- `pointDifferenceHome` Point Difference (Home)
            >- `position` Standings Position
            >- `scoredAgainst` Score Against
            >- `scoredAgainstAway` Score Against (Away)
            >- `scoredAgainstHome` Score Against (Home)
            >- `scoredFor` Score For
            >- `scoredForAway` Score For (Away)
            >- `scoredForHome` Score For (Home)
            >- `standingPoints` Standing Points for competitor
            >- `standingPointsAway` Standing Points for competitor (Away)
            >- `standingPointsGiven` Standing Points Given away
            >- `standingPointsHome` Standing Points for competitor (Home)
            >- `streak` Winning Streak for competitor
            >- `streakAway` Winning Streak for competitor (Away)
            >- `streakHome` Winning Streak for competitor (Home)
            >- `washouts` Washouts
            >- `winPercentage` Win Percentage
            >- `winPercentageAway` Win Percentage (Away)
            >- `winPercentageHome` Win Percentage (Home)
            >- `wins` Games Won
            >- `winsAway` Games Won (Away)
            >- `winsHome` Games Won (Home)
        adjustment_value (Union[Unset, float]): Value of the adjustment field Example: 2.3.
        reason_type (Union[Unset, str]): Reason type of the adjustment Example: DISCIPLINE.
        reason_description (Union[None, Unset, str]): Reason for the adjustment Example: Points lost due to discipline
            issues.
        grouping_key (Union[None, Unset, str]): Grouping Key to allow bulk deletions or listing by the key Example:
            KEYA123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    standing_adjustment_id: Union[Unset, UUID] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "StandingAdjustmentModelSeason"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "StandingAdjustmentModelEntity"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "StandingAdjustmentModelOrganization"] = UNSET
    round_code: Union[None, Unset, str] = UNSET
    round_: Union[Unset, "StandingAdjustmentModelRound"] = UNSET
    round_number: Union[None, Unset, str] = UNSET
    stage_code: Union[None, Unset, str] = UNSET
    stage: Union[Unset, "StandingAdjustmentModelStage"] = UNSET
    pool_code: Union[None, Unset, str] = UNSET
    pool: Union[Unset, "StandingAdjustmentModelPool"] = UNSET
    division_id: Union[None, UUID, Unset] = UNSET
    division: Union[Unset, "StandingAdjustmentModelDivision"] = UNSET
    conference_id: Union[None, UUID, Unset] = UNSET
    conference: Union[Unset, "StandingAdjustmentModelConference"] = UNSET
    apply_to_all_standings: Union[Unset, bool] = UNSET
    adjustment_group: Union[Unset, StandingAdjustmentModelAdjustmentGroup] = UNSET
    adjustment_type: Union[Unset, StandingAdjustmentModelAdjustmentType] = UNSET
    adjustment_field: Union[Unset, StandingAdjustmentModelAdjustmentField] = UNSET
    adjustment_value: Union[Unset, float] = UNSET
    reason_type: Union[Unset, str] = UNSET
    reason_description: Union[None, Unset, str] = UNSET
    grouping_key: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        standing_adjustment_id: Union[Unset, str] = UNSET
        if not isinstance(self.standing_adjustment_id, Unset):
            standing_adjustment_id = str(self.standing_adjustment_id)

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        round_code: Union[None, Unset, str]
        if isinstance(self.round_code, Unset):
            round_code = UNSET
        else:
            round_code = self.round_code

        round_: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.round_, Unset):
            round_ = self.round_.to_dict()

        round_number: Union[None, Unset, str]
        if isinstance(self.round_number, Unset):
            round_number = UNSET
        else:
            round_number = self.round_number

        stage_code: Union[None, Unset, str]
        if isinstance(self.stage_code, Unset):
            stage_code = UNSET
        else:
            stage_code = self.stage_code

        stage: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.stage, Unset):
            stage = self.stage.to_dict()

        pool_code: Union[None, Unset, str]
        if isinstance(self.pool_code, Unset):
            pool_code = UNSET
        else:
            pool_code = self.pool_code

        pool: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pool, Unset):
            pool = self.pool.to_dict()

        division_id: Union[None, Unset, str]
        if isinstance(self.division_id, Unset):
            division_id = UNSET
        elif isinstance(self.division_id, UUID):
            division_id = str(self.division_id)
        else:
            division_id = self.division_id

        division: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.division, Unset):
            division = self.division.to_dict()

        conference_id: Union[None, Unset, str]
        if isinstance(self.conference_id, Unset):
            conference_id = UNSET
        elif isinstance(self.conference_id, UUID):
            conference_id = str(self.conference_id)
        else:
            conference_id = self.conference_id

        conference: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.conference, Unset):
            conference = self.conference.to_dict()

        apply_to_all_standings = self.apply_to_all_standings

        adjustment_group: Union[Unset, str] = UNSET
        if not isinstance(self.adjustment_group, Unset):
            adjustment_group = self.adjustment_group.value

        adjustment_type: Union[Unset, str] = UNSET
        if not isinstance(self.adjustment_type, Unset):
            adjustment_type = self.adjustment_type.value

        adjustment_field: Union[Unset, str] = UNSET
        if not isinstance(self.adjustment_field, Unset):
            adjustment_field = self.adjustment_field.value

        adjustment_value = self.adjustment_value

        reason_type = self.reason_type

        reason_description: Union[None, Unset, str]
        if isinstance(self.reason_description, Unset):
            reason_description = UNSET
        else:
            reason_description = self.reason_description

        grouping_key: Union[None, Unset, str]
        if isinstance(self.grouping_key, Unset):
            grouping_key = UNSET
        else:
            grouping_key = self.grouping_key

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if standing_adjustment_id is not UNSET:
            field_dict["standingAdjustmentId"] = standing_adjustment_id
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if round_code is not UNSET:
            field_dict["roundCode"] = round_code
        if round_ is not UNSET:
            field_dict["round"] = round_
        if round_number is not UNSET:
            field_dict["roundNumber"] = round_number
        if stage_code is not UNSET:
            field_dict["stageCode"] = stage_code
        if stage is not UNSET:
            field_dict["stage"] = stage
        if pool_code is not UNSET:
            field_dict["poolCode"] = pool_code
        if pool is not UNSET:
            field_dict["pool"] = pool
        if division_id is not UNSET:
            field_dict["divisionId"] = division_id
        if division is not UNSET:
            field_dict["division"] = division
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if conference is not UNSET:
            field_dict["conference"] = conference
        if apply_to_all_standings is not UNSET:
            field_dict["applyToAllStandings"] = apply_to_all_standings
        if adjustment_group is not UNSET:
            field_dict["adjustmentGroup"] = adjustment_group
        if adjustment_type is not UNSET:
            field_dict["adjustmentType"] = adjustment_type
        if adjustment_field is not UNSET:
            field_dict["adjustmentField"] = adjustment_field
        if adjustment_value is not UNSET:
            field_dict["adjustmentValue"] = adjustment_value
        if reason_type is not UNSET:
            field_dict["reasonType"] = reason_type
        if reason_description is not UNSET:
            field_dict["reasonDescription"] = reason_description
        if grouping_key is not UNSET:
            field_dict["groupingKey"] = grouping_key
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.standing_adjustment_model_conference import StandingAdjustmentModelConference
        from ..models.standing_adjustment_model_division import StandingAdjustmentModelDivision
        from ..models.standing_adjustment_model_entity import StandingAdjustmentModelEntity
        from ..models.standing_adjustment_model_organization import StandingAdjustmentModelOrganization
        from ..models.standing_adjustment_model_pool import StandingAdjustmentModelPool
        from ..models.standing_adjustment_model_round import StandingAdjustmentModelRound
        from ..models.standing_adjustment_model_season import StandingAdjustmentModelSeason
        from ..models.standing_adjustment_model_stage import StandingAdjustmentModelStage

        d = dict(src_dict)
        _standing_adjustment_id = d.pop("standingAdjustmentId", UNSET)
        standing_adjustment_id: Union[Unset, UUID]
        if isinstance(_standing_adjustment_id, Unset):
            standing_adjustment_id = UNSET
        else:
            standing_adjustment_id = UUID(_standing_adjustment_id)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, StandingAdjustmentModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = StandingAdjustmentModelSeason.from_dict(_season)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, StandingAdjustmentModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = StandingAdjustmentModelEntity.from_dict(_entity)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, StandingAdjustmentModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = StandingAdjustmentModelOrganization.from_dict(_organization)

        def _parse_round_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_code = _parse_round_code(d.pop("roundCode", UNSET))

        _round_ = d.pop("round", UNSET)
        round_: Union[Unset, StandingAdjustmentModelRound]
        if isinstance(_round_, Unset):
            round_ = UNSET
        else:
            round_ = StandingAdjustmentModelRound.from_dict(_round_)

        def _parse_round_number(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        round_number = _parse_round_number(d.pop("roundNumber", UNSET))

        def _parse_stage_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        stage_code = _parse_stage_code(d.pop("stageCode", UNSET))

        _stage = d.pop("stage", UNSET)
        stage: Union[Unset, StandingAdjustmentModelStage]
        if isinstance(_stage, Unset):
            stage = UNSET
        else:
            stage = StandingAdjustmentModelStage.from_dict(_stage)

        def _parse_pool_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        pool_code = _parse_pool_code(d.pop("poolCode", UNSET))

        _pool = d.pop("pool", UNSET)
        pool: Union[Unset, StandingAdjustmentModelPool]
        if isinstance(_pool, Unset):
            pool = UNSET
        else:
            pool = StandingAdjustmentModelPool.from_dict(_pool)

        def _parse_division_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                division_id_type_0 = UUID(data)

                return division_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        division_id = _parse_division_id(d.pop("divisionId", UNSET))

        _division = d.pop("division", UNSET)
        division: Union[Unset, StandingAdjustmentModelDivision]
        if isinstance(_division, Unset):
            division = UNSET
        else:
            division = StandingAdjustmentModelDivision.from_dict(_division)

        def _parse_conference_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                conference_id_type_0 = UUID(data)

                return conference_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        conference_id = _parse_conference_id(d.pop("conferenceId", UNSET))

        _conference = d.pop("conference", UNSET)
        conference: Union[Unset, StandingAdjustmentModelConference]
        if isinstance(_conference, Unset):
            conference = UNSET
        else:
            conference = StandingAdjustmentModelConference.from_dict(_conference)

        apply_to_all_standings = d.pop("applyToAllStandings", UNSET)

        _adjustment_group = d.pop("adjustmentGroup", UNSET)
        adjustment_group: Union[Unset, StandingAdjustmentModelAdjustmentGroup]
        if isinstance(_adjustment_group, Unset):
            adjustment_group = UNSET
        else:
            adjustment_group = StandingAdjustmentModelAdjustmentGroup(_adjustment_group)

        _adjustment_type = d.pop("adjustmentType", UNSET)
        adjustment_type: Union[Unset, StandingAdjustmentModelAdjustmentType]
        if isinstance(_adjustment_type, Unset):
            adjustment_type = UNSET
        else:
            adjustment_type = StandingAdjustmentModelAdjustmentType(_adjustment_type)

        _adjustment_field = d.pop("adjustmentField", UNSET)
        adjustment_field: Union[Unset, StandingAdjustmentModelAdjustmentField]
        if isinstance(_adjustment_field, Unset):
            adjustment_field = UNSET
        else:
            adjustment_field = StandingAdjustmentModelAdjustmentField(_adjustment_field)

        adjustment_value = d.pop("adjustmentValue", UNSET)

        reason_type = d.pop("reasonType", UNSET)

        def _parse_reason_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        reason_description = _parse_reason_description(d.pop("reasonDescription", UNSET))

        def _parse_grouping_key(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        grouping_key = _parse_grouping_key(d.pop("groupingKey", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        standing_adjustment_model = cls(
            standing_adjustment_id=standing_adjustment_id,
            season_id=season_id,
            season=season,
            entity_id=entity_id,
            entity=entity,
            organization_id=organization_id,
            organization=organization,
            round_code=round_code,
            round_=round_,
            round_number=round_number,
            stage_code=stage_code,
            stage=stage,
            pool_code=pool_code,
            pool=pool,
            division_id=division_id,
            division=division,
            conference_id=conference_id,
            conference=conference,
            apply_to_all_standings=apply_to_all_standings,
            adjustment_group=adjustment_group,
            adjustment_type=adjustment_type,
            adjustment_field=adjustment_field,
            adjustment_value=adjustment_value,
            reason_type=reason_type,
            reason_description=reason_description,
            grouping_key=grouping_key,
            updated=updated,
            added=added,
        )

        return standing_adjustment_model



from enum import Enum


class OrganizationListRegionType(str, Enum):
    INTERNATIONAL = "INTERNATIONAL"
    LOCAL = "LOCAL"
    NATIONAL = "NATIONAL"
    STATE = "STATE"

    def __str__(self) -> str:
        return str(self.value)



"""Handball API Pytest Script (for new API)
Tests various endpoints of the Sportradar DataCore API for handball.
Author: Michael Adams, 2025
"""

import json
import os
from collections.abc import Sequence
from pathlib import Path
from typing import Any

import pytest
from dotenv import load_dotenv

from sportradar_datacore_api.handball import HandballAPI


@pytest.fixture(scope="module")
def api() -> HandballAPI:
    """Fixture to initialize the HandballAPI client."""
    load_dotenv(".env", override=True)
    required = [
        "BASE_URL",
        "AUTH_URL",
        "CLIENT_ID",
        "CLIENT_SECRET",
        "CLIENT_ORGANIZATION_ID",
    ]
    missing = [key for key in required if not os.getenv(key)]
    if missing:
        pytest.skip(
            "Missing required environment variables for live API tests: "
            + ", ".join(missing)
        )
    return HandballAPI(
        base_url=os.getenv("BASE_URL", ""),
        auth_url=os.getenv("AUTH_URL", ""),
        client_id=os.getenv("CLIENT_ID", ""),
        client_secret=os.getenv("CLIENT_SECRET", ""),
        org_id=os.getenv("CLIENT_ORGANIZATION_ID"),
        scopes=["read:organization"],
        sport="handball",
    )


@pytest.fixture(scope="module")
def log_dir() -> Path:
    """Fixture to create a log directory for test outputs."""
    path = Path("log")
    path.mkdir(parents=True, exist_ok=True)
    return path


def save_result(log_dir: Path, title: str, data: Any) -> None:
    """Utility to save test results to JSON files."""
    if os.getenv("SRD_SKIP_TEST_LOGS") == "1":
        return None
    path = log_dir / f"{title.lower().replace(' ', '_')}.json"
    path.write_text(json.dumps(data, indent=2, default=str), encoding="utf-8")
    return None


def _first_fixture_id(fixtures: Sequence[Any]) -> str | None:
    for fixture in fixtures:
        if isinstance(fixture, dict):
            fixture_id = fixture.get("fixture_id") or fixture.get("fixtureId")
        else:
            fixture_id = getattr(fixture, "fixture_id", None)
        if fixture_id:
            return fixture_id
    return None


def test_competition_id(api: HandballAPI, log_dir: Path) -> None:
    """Test resolving competition ID by name."""
    comp_id = api.get_competition_id_by_name("1. Handball-Bundesliga")
    assert comp_id, "No competition ID found"
    save_result(log_dir, "competition_id", {"competition_id": comp_id})


def test_season_id(api: HandballAPI, log_dir: Path) -> None:
    """Test resolving season ID by year."""
    comp_id = api.get_competition_id_by_name("1. Handball-Bundesliga")
    season_id = api.get_season_id_by_year(comp_id, 2023)
    assert season_id, "No season ID found"
    save_result(log_dir, "season_id", {"season_id": season_id})


def test_list_fixtures(api: HandballAPI, log_dir: Path) -> None:
    """Test listing fixtures for a season."""
    comp_id = api.get_competition_id_by_name("1. Handball-Bundesliga")
    season_id = api.get_season_id_by_year(comp_id, 2023)
    fixtures = api.list_matches_by_season(season_id)
    assert fixtures, "No fixtures found"
    # Convert objects to dicts for JSON serialization
    fixtures_dict = [f.__dict__ if hasattr(f, "__dict__") else f for f in fixtures]
    save_result(log_dir, "fixtures", fixtures_dict)


def test_fixture_events(api: HandballAPI, log_dir: Path) -> None:
    """Test getting events for a fixture."""
    comp_id = api.get_competition_id_by_name("1. Handball-Bundesliga")
    season_id = api.get_season_id_by_year(comp_id, 2023)
    fixtures = api.list_matches_by_season(season_id)
    assert fixtures, "No fixtures found"
    fixture_id = _first_fixture_id(fixtures)
    assert fixture_id, "No fixture ID found"
    events = api.get_match_events(fixture_id, setup_only=False, with_scores=True)
    assert events is not None, "No events found"
    save_result(log_dir, "fixture_events", events)


def test_full_flow(api: HandballAPI, log_dir: Path) -> None:
    """Run the full test flow."""
    comp_id = api.get_competition_id_by_name("1. Handball-Bundesliga")
    assert comp_id, "No competition ID found"
    season_id = api.get_season_id_by_year(comp_id, 2023)
    assert season_id, "No season ID found"
    fixtures = api.list_matches_by_season(season_id)
    assert fixtures, "No fixtures found"
    fixture_id = _first_fixture_id(fixtures)
    assert fixture_id, "No fixture ID found"
    events = api.get_match_events(fixture_id, setup_only=False, with_scores=True)
    assert events is not None, "No events found"


if __name__ == "__main__":
    pytest.main(["-v", __file__])



from enum import Enum


class VideoSubscriptionModelAudio(str, Enum):
    AMBIENCE = "AMBIENCE"
    BOTH = "BOTH"
    BOTH_SPLIT_LR = "BOTH_SPLIT_LR"
    COMMENTARY = "COMMENTARY"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.season_teams_model_roster_status import SeasonTeamsModelRosterStatus
from ..models.season_teams_model_status import SeasonTeamsModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_teams_model_conference import SeasonTeamsModelConference
    from ..models.season_teams_model_division import SeasonTeamsModelDivision
    from ..models.season_teams_model_entity import SeasonTeamsModelEntity
    from ..models.season_teams_model_organization import SeasonTeamsModelOrganization
    from ..models.season_teams_model_season import SeasonTeamsModelSeason


T = TypeVar("T", bound="SeasonTeamsModel")


@_attrs_define
class SeasonTeamsModel:
    """
    Attributes:
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonTeamsModelSeason]): The season linked to this record
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonTeamsModelOrganization]): The organization that this season teams belongs to
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, SeasonTeamsModelEntity]): The team information
        conference_id (Union[None, UUID, Unset]): The unique identifier of the conference Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        conference (Union[Unset, SeasonTeamsModelConference]): The conference information
        division_id (Union[None, UUID, Unset]): The unique identifier of the division Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        division (Union[Unset, SeasonTeamsModelDivision]): The division information
        roster_status (Union[Unset, SeasonTeamsModelRosterStatus]): The status of the TEAM season teams
            >- `APPROVED` Approved
            >- `PENDING` Pending
            >- `REJECTED` Rejected
            >- `SUBMITTED` Submitted
            >- `UNKNOWN` Unknown
             Default: SeasonTeamsModelRosterStatus.UNKNOWN. Example: APPROVED.
        status (Union[Unset, SeasonTeamsModelStatus]): Status
            >- `ACTIVE` Active
            >- `INACTIVE` Inactive
            >- `PENDING` Pending
             Example: ACTIVE.
        seed (Union[None, Unset, int]): Initial seeding Example: 1.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonTeamsModelSeason"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonTeamsModelOrganization"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "SeasonTeamsModelEntity"] = UNSET
    conference_id: Union[None, UUID, Unset] = UNSET
    conference: Union[Unset, "SeasonTeamsModelConference"] = UNSET
    division_id: Union[None, UUID, Unset] = UNSET
    division: Union[Unset, "SeasonTeamsModelDivision"] = UNSET
    roster_status: Union[Unset, SeasonTeamsModelRosterStatus] = SeasonTeamsModelRosterStatus.UNKNOWN
    status: Union[Unset, SeasonTeamsModelStatus] = UNSET
    seed: Union[None, Unset, int] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        conference_id: Union[None, Unset, str]
        if isinstance(self.conference_id, Unset):
            conference_id = UNSET
        elif isinstance(self.conference_id, UUID):
            conference_id = str(self.conference_id)
        else:
            conference_id = self.conference_id

        conference: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.conference, Unset):
            conference = self.conference.to_dict()

        division_id: Union[None, Unset, str]
        if isinstance(self.division_id, Unset):
            division_id = UNSET
        elif isinstance(self.division_id, UUID):
            division_id = str(self.division_id)
        else:
            division_id = self.division_id

        division: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.division, Unset):
            division = self.division.to_dict()

        roster_status: Union[Unset, str] = UNSET
        if not isinstance(self.roster_status, Unset):
            roster_status = self.roster_status.value

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        seed: Union[None, Unset, int]
        if isinstance(self.seed, Unset):
            seed = UNSET
        else:
            seed = self.seed

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if conference_id is not UNSET:
            field_dict["conferenceId"] = conference_id
        if conference is not UNSET:
            field_dict["conference"] = conference
        if division_id is not UNSET:
            field_dict["divisionId"] = division_id
        if division is not UNSET:
            field_dict["division"] = division
        if roster_status is not UNSET:
            field_dict["rosterStatus"] = roster_status
        if status is not UNSET:
            field_dict["status"] = status
        if seed is not UNSET:
            field_dict["seed"] = seed
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_teams_model_conference import SeasonTeamsModelConference
        from ..models.season_teams_model_division import SeasonTeamsModelDivision
        from ..models.season_teams_model_entity import SeasonTeamsModelEntity
        from ..models.season_teams_model_organization import SeasonTeamsModelOrganization
        from ..models.season_teams_model_season import SeasonTeamsModelSeason

        d = dict(src_dict)
        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonTeamsModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonTeamsModelSeason.from_dict(_season)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonTeamsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonTeamsModelOrganization.from_dict(_organization)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, SeasonTeamsModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = SeasonTeamsModelEntity.from_dict(_entity)

        def _parse_conference_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                conference_id_type_0 = UUID(data)

                return conference_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        conference_id = _parse_conference_id(d.pop("conferenceId", UNSET))

        _conference = d.pop("conference", UNSET)
        conference: Union[Unset, SeasonTeamsModelConference]
        if isinstance(_conference, Unset):
            conference = UNSET
        else:
            conference = SeasonTeamsModelConference.from_dict(_conference)

        def _parse_division_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                division_id_type_0 = UUID(data)

                return division_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        division_id = _parse_division_id(d.pop("divisionId", UNSET))

        _division = d.pop("division", UNSET)
        division: Union[Unset, SeasonTeamsModelDivision]
        if isinstance(_division, Unset):
            division = UNSET
        else:
            division = SeasonTeamsModelDivision.from_dict(_division)

        _roster_status = d.pop("rosterStatus", UNSET)
        roster_status: Union[Unset, SeasonTeamsModelRosterStatus]
        if isinstance(_roster_status, Unset):
            roster_status = UNSET
        else:
            roster_status = SeasonTeamsModelRosterStatus(_roster_status)

        _status = d.pop("status", UNSET)
        status: Union[Unset, SeasonTeamsModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = SeasonTeamsModelStatus(_status)

        def _parse_seed(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        seed = _parse_seed(d.pop("seed", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        season_teams_model = cls(
            season_id=season_id,
            season=season,
            organization_id=organization_id,
            organization=organization,
            entity_id=entity_id,
            entity=entity,
            conference_id=conference_id,
            conference=conference,
            division_id=division_id,
            division=division,
            roster_status=roster_status,
            status=status,
            seed=seed,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return season_teams_model



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="Model")


@_attrs_define
class Model:
    """
    Attributes:
        success (Union[Unset, bool]): Was the call a success? Example: True.
    """

    success: Union[Unset, bool] = UNSET

    def to_dict(self) -> dict[str, Any]:
        success = self.success

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if success is not UNSET:
            field_dict["success"] = success

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        success = d.pop("success", UNSET)

        model = cls(
            success=success,
        )

        return model



from enum import Enum


class AwardsListSeasonsAward(str, Enum):
    ALL_TEAM = "ALL_TEAM"
    COACH = "COACH"
    DEFENSIVE = "DEFENSIVE"
    DEFENSIVE_TEAM = "DEFENSIVE_TEAM"
    HALL = "HALL"
    HONOUR = "HONOUR"
    MIP = "MIP"
    MVP = "MVP"
    OTHER = "OTHER"
    ROOKIE = "ROOKIE"
    VALUE_7 = "6th_MAN"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ResponseLinks")


@_attrs_define
class ResponseLinks:
    """
    Attributes:
        self_ (Union[Unset, str]): The URI referencing this request.
        next_ (Union[Unset, str]): The URI referencing the 'next' page, if more data is available.
        previous (Union[Unset, str]): The URI referencing the 'previous' page, if the request is not on the first page.
    """

    self_: Union[Unset, str] = UNSET
    next_: Union[Unset, str] = UNSET
    previous: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        self_ = self.self_

        next_ = self.next_

        previous = self.previous

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if self_ is not UNSET:
            field_dict["self"] = self_
        if next_ is not UNSET:
            field_dict["next"] = next_
        if previous is not UNSET:
            field_dict["previous"] = previous

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        self_ = d.pop("self", UNSET)

        next_ = d.pop("next", UNSET)

        previous = d.pop("previous", UNSET)

        response_links = cls(
            self_=self_,
            next_=next_,
            previous=previous,
        )

        response_links.additional_properties = d
        return response_links

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="StandingModelPointsAdditionalProperty")


@_attrs_define
class StandingModelPointsAdditionalProperty:
    """Type of points

    Example:
        default

    Attributes:
        bonus_standing_points (Union[Unset, float]): Bonus Standing points
        penalty_standing_points (Union[Unset, float]): Penalty Standing points
        bye_standing_points (Union[Unset, float]): Bye Standing points
        team_differential (Union[Unset, float]): Differential of Won-Lost
        team_differential_home (Union[Unset, float]): Differential of Won-Lost
        team_differential_away (Union[Unset, float]): Differential of Won-Lost
        games_behind (Union[Unset, float]): Games behind leading competitor
        standing_points (Union[Unset, float]): Standing Points for competitor
        standing_points_home (Union[Unset, float]): Standing Points for competitor at Home
        standing_points_away (Union[Unset, float]): Standing Points for competitor away
        standing_points_given (Union[Unset, float]): Standing Points Given away for this competitor
    """

    bonus_standing_points: Union[Unset, float] = UNSET
    penalty_standing_points: Union[Unset, float] = UNSET
    bye_standing_points: Union[Unset, float] = UNSET
    team_differential: Union[Unset, float] = UNSET
    team_differential_home: Union[Unset, float] = UNSET
    team_differential_away: Union[Unset, float] = UNSET
    games_behind: Union[Unset, float] = UNSET
    standing_points: Union[Unset, float] = UNSET
    standing_points_home: Union[Unset, float] = UNSET
    standing_points_away: Union[Unset, float] = UNSET
    standing_points_given: Union[Unset, float] = UNSET

    def to_dict(self) -> dict[str, Any]:
        bonus_standing_points = self.bonus_standing_points

        penalty_standing_points = self.penalty_standing_points

        bye_standing_points = self.bye_standing_points

        team_differential = self.team_differential

        team_differential_home = self.team_differential_home

        team_differential_away = self.team_differential_away

        games_behind = self.games_behind

        standing_points = self.standing_points

        standing_points_home = self.standing_points_home

        standing_points_away = self.standing_points_away

        standing_points_given = self.standing_points_given

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if bonus_standing_points is not UNSET:
            field_dict["bonusStandingPoints"] = bonus_standing_points
        if penalty_standing_points is not UNSET:
            field_dict["penaltyStandingPoints"] = penalty_standing_points
        if bye_standing_points is not UNSET:
            field_dict["byeStandingPoints"] = bye_standing_points
        if team_differential is not UNSET:
            field_dict["teamDifferential"] = team_differential
        if team_differential_home is not UNSET:
            field_dict["teamDifferentialHome"] = team_differential_home
        if team_differential_away is not UNSET:
            field_dict["teamDifferentialAway"] = team_differential_away
        if games_behind is not UNSET:
            field_dict["gamesBehind"] = games_behind
        if standing_points is not UNSET:
            field_dict["standingPoints"] = standing_points
        if standing_points_home is not UNSET:
            field_dict["standingPointsHome"] = standing_points_home
        if standing_points_away is not UNSET:
            field_dict["standingPointsAway"] = standing_points_away
        if standing_points_given is not UNSET:
            field_dict["standingPointsGiven"] = standing_points_given

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        bonus_standing_points = d.pop("bonusStandingPoints", UNSET)

        penalty_standing_points = d.pop("penaltyStandingPoints", UNSET)

        bye_standing_points = d.pop("byeStandingPoints", UNSET)

        team_differential = d.pop("teamDifferential", UNSET)

        team_differential_home = d.pop("teamDifferentialHome", UNSET)

        team_differential_away = d.pop("teamDifferentialAway", UNSET)

        games_behind = d.pop("gamesBehind", UNSET)

        standing_points = d.pop("standingPoints", UNSET)

        standing_points_home = d.pop("standingPointsHome", UNSET)

        standing_points_away = d.pop("standingPointsAway", UNSET)

        standing_points_given = d.pop("standingPointsGiven", UNSET)

        standing_model_points_additional_property = cls(
            bonus_standing_points=bonus_standing_points,
            penalty_standing_points=penalty_standing_points,
            bye_standing_points=bye_standing_points,
            team_differential=team_differential,
            team_differential_home=team_differential_home,
            team_differential_away=team_differential_away,
            games_behind=games_behind,
            standing_points=standing_points,
            standing_points_home=standing_points_home,
            standing_points_away=standing_points_away,
            standing_points_given=standing_points_given,
        )

        return standing_model_points_additional_property



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="ResponseMetaData")


@_attrs_define
class ResponseMetaData:
    """
    Attributes:
        version (Union[Unset, int]): The version of the API in use for this call Example: 1.
        code_version (Union[Unset, str]): A string indicating the version of the code that handled this request Example:
            d6cd1e2bd19e03a81132a23b2025920577f84e37.
        code (Union[Unset, int]): The HTTP response code for this request Example: 200.
        time (Union[Unset, datetime.datetime]): The date/time this request was made (in UTC). Example:
            2018-06-05T23:43:41.227Z.
        from_cache (Union[Unset, bool]): Was this request served directly from the cache?
        count (Union[Unset, int]): The number of records being returned Example: 7.
        limit (Union[Unset, int]): The record limit in place for this request Example: 10.
        offset (Union[Unset, int]): The record offset in place for this request Example: 10.
        generation_time (Union[Unset, float]): The number of seconds taken to generate this request. Example: 0.011604.
    """

    version: Union[Unset, int] = UNSET
    code_version: Union[Unset, str] = UNSET
    code: Union[Unset, int] = UNSET
    time: Union[Unset, datetime.datetime] = UNSET
    from_cache: Union[Unset, bool] = UNSET
    count: Union[Unset, int] = UNSET
    limit: Union[Unset, int] = UNSET
    offset: Union[Unset, int] = UNSET
    generation_time: Union[Unset, float] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        version = self.version

        code_version = self.code_version

        code = self.code

        time: Union[Unset, str] = UNSET
        if not isinstance(self.time, Unset):
            time = self.time.isoformat()

        from_cache = self.from_cache

        count = self.count

        limit = self.limit

        offset = self.offset

        generation_time = self.generation_time

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if version is not UNSET:
            field_dict["version"] = version
        if code_version is not UNSET:
            field_dict["codeVersion"] = code_version
        if code is not UNSET:
            field_dict["code"] = code
        if time is not UNSET:
            field_dict["time"] = time
        if from_cache is not UNSET:
            field_dict["fromCache"] = from_cache
        if count is not UNSET:
            field_dict["count"] = count
        if limit is not UNSET:
            field_dict["limit"] = limit
        if offset is not UNSET:
            field_dict["offset"] = offset
        if generation_time is not UNSET:
            field_dict["generationTime"] = generation_time

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        version = d.pop("version", UNSET)

        code_version = d.pop("codeVersion", UNSET)

        code = d.pop("code", UNSET)

        _time = d.pop("time", UNSET)
        time: Union[Unset, datetime.datetime]
        if isinstance(_time, Unset):
            time = UNSET
        else:
            time = isoparse(_time)

        from_cache = d.pop("fromCache", UNSET)

        count = d.pop("count", UNSET)

        limit = d.pop("limit", UNSET)

        offset = d.pop("offset", UNSET)

        generation_time = d.pop("generationTime", UNSET)

        response_meta_data = cls(
            version=version,
            code_version=code_version,
            code=code,
            time=time,
            from_cache=from_cache,
            count=count,
            limit=limit,
            offset=offset,
            generation_time=generation_time,
        )

        response_meta_data.additional_properties = d
        return response_meta_data

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.video_stream_inputs_model_audio_ambience_channel import VideoStreamInputsModelAudioAmbienceChannel
from ..models.video_stream_inputs_model_audio_commentary_channel import VideoStreamInputsModelAudioCommentaryChannel
from ..models.video_stream_inputs_model_feed_type import VideoStreamInputsModelFeedType
from ..models.video_stream_inputs_model_input_resolution import VideoStreamInputsModelInputResolution
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.video_stream_inputs_model_competition import VideoStreamInputsModelCompetition
    from ..models.video_stream_inputs_model_fixture import VideoStreamInputsModelFixture
    from ..models.video_stream_inputs_model_organization import VideoStreamInputsModelOrganization
    from ..models.video_stream_inputs_model_venue import VideoStreamInputsModelVenue


T = TypeVar("T", bound="VideoStreamInputsModel")


@_attrs_define
class VideoStreamInputsModel:
    """
    Attributes:
        video_input_id (Union[Unset, UUID]): The unique identifier of the video input Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        master_venue_id (Union[Unset, UUID]): The unique identifier of the master venue Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, VideoStreamInputsModelOrganization]): The organization that this Video Stream Inputs
            belongs to
        venue_id (Union[Unset, UUID]): The unique identifier of the venue Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        venue (Union[Unset, VideoStreamInputsModelVenue]): The venue that this match belongs to
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, VideoStreamInputsModelCompetition]): The competition that this season belongs to
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, VideoStreamInputsModelFixture]): The match
        start_time_local (Union[Unset, datetime.datetime]): Start time (Local). Example: 2018-08-16T02:00:00.
        start_time_utc (Union[Unset, datetime.datetime]): Start time (UTC). This is automatically generated based on the
            timezone of the venue. Example: 2018-08-16T02:00:00.
        finish_recording_time_utc (Union[Unset, datetime.datetime]): (TO BE REMOVED) Finish Recording time of the stream
            (if not set, is calculated as startTimeUTC + durationFull from matches)
        estimated_finish_time_utc (Union[Unset, datetime.datetime]): Finish Recording time of the stream (if not set, is
            calculated as startTimeUTC + durationFull from matches)
        provider (Union[Unset, str]): The code for the provider of the file Example: Test Provider.
        locale (Union[Unset, str]): The locale of the video Example: fr-FR.
        source_number (Union[Unset, int]): Unique identifier for the video source. This is unique for the
            provider/fixtureId/locale combination.  Unless the provider is supplying multiple sources per fixture/locale
            then this is normally 1. Default: 1. Example: 1.
        feed_type (Union[Unset, VideoStreamInputsModelFeedType]): Type of video input
            >- `ADDITIONAL_ANGLE` Additional angle
            >- `LOW_LATENCY` Low Latency
            >- `PRIMARY` Primary
             Example: PRIMARY.
        input_resolution (Union[Unset, VideoStreamInputsModelInputResolution]): The resolution of the video input
            >- `1080` 1920 x 1080
            >- `288` 512 x 288
            >- `720` 1280 x 720
             Example: 720.
        fps (Union[Unset, int]): fps for the video stream Default: 25. Example: 25.
        name (Union[Unset, str]): The name of the video source
        audio_ambience_channel (Union[Unset, VideoStreamInputsModelAudioAmbienceChannel]): audioAmbienceChannel
            >- `CHANNEL_BOTH` Both channels
            >- `CHANNEL_LEFT` Channel left
            >- `CHANNEL_RIGHT` Channel right
            >- `NONE` None
             Example: CHANNEL_BOTH.
        audio_commentary_channel (Union[Unset, VideoStreamInputsModelAudioCommentaryChannel]): audioCommentaryChannel
            >- `CHANNEL_BOTH` Both channels
            >- `CHANNEL_LEFT` Channel left
            >- `CHANNEL_RIGHT` Channel right
            >- `NONE` None
             Example: CHANNEL_BOTH.
        platform_provider_override (Union[None, Unset, str]): Override Video Provider configuration Example: LOCAL.
        input_url (Union[Unset, str]): The URL where the video should be sent Example:
            rtmp://1ejcn5c-4wmytr5.vi.atriumsports.com/inputin1/inputin1.
        stream_name (Union[Unset, str]): The name/stream key of the RTMP stream. This is an optional part of the RTMP
            url - not a text description.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    video_input_id: Union[Unset, UUID] = UNSET
    master_venue_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "VideoStreamInputsModelOrganization"] = UNSET
    venue_id: Union[Unset, UUID] = UNSET
    venue: Union[Unset, "VideoStreamInputsModelVenue"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "VideoStreamInputsModelCompetition"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "VideoStreamInputsModelFixture"] = UNSET
    start_time_local: Union[Unset, datetime.datetime] = UNSET
    start_time_utc: Union[Unset, datetime.datetime] = UNSET
    finish_recording_time_utc: Union[Unset, datetime.datetime] = UNSET
    estimated_finish_time_utc: Union[Unset, datetime.datetime] = UNSET
    provider: Union[Unset, str] = UNSET
    locale: Union[Unset, str] = UNSET
    source_number: Union[Unset, int] = 1
    feed_type: Union[Unset, VideoStreamInputsModelFeedType] = UNSET
    input_resolution: Union[Unset, VideoStreamInputsModelInputResolution] = UNSET
    fps: Union[Unset, int] = 25
    name: Union[Unset, str] = UNSET
    audio_ambience_channel: Union[Unset, VideoStreamInputsModelAudioAmbienceChannel] = UNSET
    audio_commentary_channel: Union[Unset, VideoStreamInputsModelAudioCommentaryChannel] = UNSET
    platform_provider_override: Union[None, Unset, str] = UNSET
    input_url: Union[Unset, str] = UNSET
    stream_name: Union[Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        video_input_id: Union[Unset, str] = UNSET
        if not isinstance(self.video_input_id, Unset):
            video_input_id = str(self.video_input_id)

        master_venue_id: Union[Unset, str] = UNSET
        if not isinstance(self.master_venue_id, Unset):
            master_venue_id = str(self.master_venue_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        venue_id: Union[Unset, str] = UNSET
        if not isinstance(self.venue_id, Unset):
            venue_id = str(self.venue_id)

        venue: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.venue, Unset):
            venue = self.venue.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        start_time_local: Union[Unset, str] = UNSET
        if not isinstance(self.start_time_local, Unset):
            start_time_local = self.start_time_local.isoformat()

        start_time_utc: Union[Unset, str] = UNSET
        if not isinstance(self.start_time_utc, Unset):
            start_time_utc = self.start_time_utc.isoformat()

        finish_recording_time_utc: Union[Unset, str] = UNSET
        if not isinstance(self.finish_recording_time_utc, Unset):
            finish_recording_time_utc = self.finish_recording_time_utc.isoformat()

        estimated_finish_time_utc: Union[Unset, str] = UNSET
        if not isinstance(self.estimated_finish_time_utc, Unset):
            estimated_finish_time_utc = self.estimated_finish_time_utc.isoformat()

        provider = self.provider

        locale = self.locale

        source_number = self.source_number

        feed_type: Union[Unset, str] = UNSET
        if not isinstance(self.feed_type, Unset):
            feed_type = self.feed_type.value

        input_resolution: Union[Unset, str] = UNSET
        if not isinstance(self.input_resolution, Unset):
            input_resolution = self.input_resolution.value

        fps = self.fps

        name = self.name

        audio_ambience_channel: Union[Unset, str] = UNSET
        if not isinstance(self.audio_ambience_channel, Unset):
            audio_ambience_channel = self.audio_ambience_channel.value

        audio_commentary_channel: Union[Unset, str] = UNSET
        if not isinstance(self.audio_commentary_channel, Unset):
            audio_commentary_channel = self.audio_commentary_channel.value

        platform_provider_override: Union[None, Unset, str]
        if isinstance(self.platform_provider_override, Unset):
            platform_provider_override = UNSET
        else:
            platform_provider_override = self.platform_provider_override

        input_url = self.input_url

        stream_name = self.stream_name

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if video_input_id is not UNSET:
            field_dict["videoInputId"] = video_input_id
        if master_venue_id is not UNSET:
            field_dict["masterVenueId"] = master_venue_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if venue_id is not UNSET:
            field_dict["venueId"] = venue_id
        if venue is not UNSET:
            field_dict["venue"] = venue
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if start_time_local is not UNSET:
            field_dict["startTimeLocal"] = start_time_local
        if start_time_utc is not UNSET:
            field_dict["startTimeUTC"] = start_time_utc
        if finish_recording_time_utc is not UNSET:
            field_dict["finishRecordingTimeUTC"] = finish_recording_time_utc
        if estimated_finish_time_utc is not UNSET:
            field_dict["estimatedFinishTimeUTC"] = estimated_finish_time_utc
        if provider is not UNSET:
            field_dict["provider"] = provider
        if locale is not UNSET:
            field_dict["locale"] = locale
        if source_number is not UNSET:
            field_dict["sourceNumber"] = source_number
        if feed_type is not UNSET:
            field_dict["feedType"] = feed_type
        if input_resolution is not UNSET:
            field_dict["inputResolution"] = input_resolution
        if fps is not UNSET:
            field_dict["fps"] = fps
        if name is not UNSET:
            field_dict["name"] = name
        if audio_ambience_channel is not UNSET:
            field_dict["audioAmbienceChannel"] = audio_ambience_channel
        if audio_commentary_channel is not UNSET:
            field_dict["audioCommentaryChannel"] = audio_commentary_channel
        if platform_provider_override is not UNSET:
            field_dict["platformProviderOverride"] = platform_provider_override
        if input_url is not UNSET:
            field_dict["inputURL"] = input_url
        if stream_name is not UNSET:
            field_dict["streamName"] = stream_name
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.video_stream_inputs_model_competition import VideoStreamInputsModelCompetition
        from ..models.video_stream_inputs_model_fixture import VideoStreamInputsModelFixture
        from ..models.video_stream_inputs_model_organization import VideoStreamInputsModelOrganization
        from ..models.video_stream_inputs_model_venue import VideoStreamInputsModelVenue

        d = dict(src_dict)
        _video_input_id = d.pop("videoInputId", UNSET)
        video_input_id: Union[Unset, UUID]
        if isinstance(_video_input_id, Unset):
            video_input_id = UNSET
        else:
            video_input_id = UUID(_video_input_id)

        _master_venue_id = d.pop("masterVenueId", UNSET)
        master_venue_id: Union[Unset, UUID]
        if isinstance(_master_venue_id, Unset):
            master_venue_id = UNSET
        else:
            master_venue_id = UUID(_master_venue_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, VideoStreamInputsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = VideoStreamInputsModelOrganization.from_dict(_organization)

        _venue_id = d.pop("venueId", UNSET)
        venue_id: Union[Unset, UUID]
        if isinstance(_venue_id, Unset):
            venue_id = UNSET
        else:
            venue_id = UUID(_venue_id)

        _venue = d.pop("venue", UNSET)
        venue: Union[Unset, VideoStreamInputsModelVenue]
        if isinstance(_venue, Unset):
            venue = UNSET
        else:
            venue = VideoStreamInputsModelVenue.from_dict(_venue)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, VideoStreamInputsModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = VideoStreamInputsModelCompetition.from_dict(_competition)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, VideoStreamInputsModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = VideoStreamInputsModelFixture.from_dict(_fixture)

        _start_time_local = d.pop("startTimeLocal", UNSET)
        start_time_local: Union[Unset, datetime.datetime]
        if isinstance(_start_time_local, Unset):
            start_time_local = UNSET
        else:
            start_time_local = isoparse(_start_time_local)

        _start_time_utc = d.pop("startTimeUTC", UNSET)
        start_time_utc: Union[Unset, datetime.datetime]
        if isinstance(_start_time_utc, Unset):
            start_time_utc = UNSET
        else:
            start_time_utc = isoparse(_start_time_utc)

        _finish_recording_time_utc = d.pop("finishRecordingTimeUTC", UNSET)
        finish_recording_time_utc: Union[Unset, datetime.datetime]
        if isinstance(_finish_recording_time_utc, Unset):
            finish_recording_time_utc = UNSET
        else:
            finish_recording_time_utc = isoparse(_finish_recording_time_utc)

        _estimated_finish_time_utc = d.pop("estimatedFinishTimeUTC", UNSET)
        estimated_finish_time_utc: Union[Unset, datetime.datetime]
        if isinstance(_estimated_finish_time_utc, Unset):
            estimated_finish_time_utc = UNSET
        else:
            estimated_finish_time_utc = isoparse(_estimated_finish_time_utc)

        provider = d.pop("provider", UNSET)

        locale = d.pop("locale", UNSET)

        source_number = d.pop("sourceNumber", UNSET)

        _feed_type = d.pop("feedType", UNSET)
        feed_type: Union[Unset, VideoStreamInputsModelFeedType]
        if isinstance(_feed_type, Unset):
            feed_type = UNSET
        else:
            feed_type = VideoStreamInputsModelFeedType(_feed_type)

        _input_resolution = d.pop("inputResolution", UNSET)
        input_resolution: Union[Unset, VideoStreamInputsModelInputResolution]
        if isinstance(_input_resolution, Unset):
            input_resolution = UNSET
        else:
            input_resolution = VideoStreamInputsModelInputResolution(_input_resolution)

        fps = d.pop("fps", UNSET)

        name = d.pop("name", UNSET)

        _audio_ambience_channel = d.pop("audioAmbienceChannel", UNSET)
        audio_ambience_channel: Union[Unset, VideoStreamInputsModelAudioAmbienceChannel]
        if isinstance(_audio_ambience_channel, Unset):
            audio_ambience_channel = UNSET
        else:
            audio_ambience_channel = VideoStreamInputsModelAudioAmbienceChannel(_audio_ambience_channel)

        _audio_commentary_channel = d.pop("audioCommentaryChannel", UNSET)
        audio_commentary_channel: Union[Unset, VideoStreamInputsModelAudioCommentaryChannel]
        if isinstance(_audio_commentary_channel, Unset):
            audio_commentary_channel = UNSET
        else:
            audio_commentary_channel = VideoStreamInputsModelAudioCommentaryChannel(_audio_commentary_channel)

        def _parse_platform_provider_override(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        platform_provider_override = _parse_platform_provider_override(d.pop("platformProviderOverride", UNSET))

        input_url = d.pop("inputURL", UNSET)

        stream_name = d.pop("streamName", UNSET)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        video_stream_inputs_model = cls(
            video_input_id=video_input_id,
            master_venue_id=master_venue_id,
            organization_id=organization_id,
            organization=organization,
            venue_id=venue_id,
            venue=venue,
            competition_id=competition_id,
            competition=competition,
            fixture_id=fixture_id,
            fixture=fixture,
            start_time_local=start_time_local,
            start_time_utc=start_time_utc,
            finish_recording_time_utc=finish_recording_time_utc,
            estimated_finish_time_utc=estimated_finish_time_utc,
            provider=provider,
            locale=locale,
            source_number=source_number,
            feed_type=feed_type,
            input_resolution=input_resolution,
            fps=fps,
            name=name,
            audio_ambience_channel=audio_ambience_channel,
            audio_commentary_channel=audio_commentary_channel,
            platform_provider_override=platform_provider_override,
            input_url=input_url,
            stream_name=stream_name,
            updated=updated,
            added=added,
        )

        return video_stream_inputs_model



from enum import Enum


class VideoStreamOutputsModelInputResolution(str, Enum):
    VALUE_0 = "288"
    VALUE_1 = "720"
    VALUE_2 = "1080"

    def __str__(self) -> str:
        return str(self.value)



from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.fls_list_fixture_live_summary_response import FlsListFixtureLiveSummaryResponse
from ...models.fls_list_response_default import FlsListResponseDefault
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    fixture_id: UUID,
    *,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["limit"] = limit

    params["offset"] = offset

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/o/{organization_id}/fixtures/{fixture_id}/summary/live",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]:
    if response.status_code == 200:
        response_200 = FlsListFixtureLiveSummaryResponse.from_dict(response.json())

        return response_200

    response_default = FlsListResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_id: str,
    fixture_id: UUID,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> Response[Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]]:
    """Match Live Summary


        Return summary data for a match currently in progress on the streaming API.  This call will only
    return data
        when the match is in progress - not post match.

        Rate limited to 2 requests every minute - returns HTTP 429 Too Many Requests if called more
    often.


    Args:
        organization_id (str):  Example: b1a23.
        fixture_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        fixture_id=fixture_id,
        limit=limit,
        offset=offset,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_id: str,
    fixture_id: UUID,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> Optional[Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]]:
    """Match Live Summary


        Return summary data for a match currently in progress on the streaming API.  This call will only
    return data
        when the match is in progress - not post match.

        Rate limited to 2 requests every minute - returns HTTP 429 Too Many Requests if called more
    often.


    Args:
        organization_id (str):  Example: b1a23.
        fixture_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]
    """

    return sync_detailed(
        organization_id=organization_id,
        fixture_id=fixture_id,
        client=client,
        limit=limit,
        offset=offset,
    ).parsed


async def asyncio_detailed(
    organization_id: str,
    fixture_id: UUID,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> Response[Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]]:
    """Match Live Summary


        Return summary data for a match currently in progress on the streaming API.  This call will only
    return data
        when the match is in progress - not post match.

        Rate limited to 2 requests every minute - returns HTTP 429 Too Many Requests if called more
    often.


    Args:
        organization_id (str):  Example: b1a23.
        fixture_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]]
    """

    kwargs = _get_kwargs(
        organization_id=organization_id,
        fixture_id=fixture_id,
        limit=limit,
        offset=offset,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_id: str,
    fixture_id: UUID,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, int] = 10,
    offset: Union[Unset, int] = UNSET,
) -> Optional[Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]]:
    """Match Live Summary


        Return summary data for a match currently in progress on the streaming API.  This call will only
    return data
        when the match is in progress - not post match.

        Rate limited to 2 requests every minute - returns HTTP 429 Too Many Requests if called more
    often.


    Args:
        organization_id (str):  Example: b1a23.
        fixture_id (UUID):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        offset (Union[Unset, int]):  Example: 10.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[FlsListFixtureLiveSummaryResponse, FlsListResponseDefault]
    """

    return (
        await asyncio_detailed(
            organization_id=organization_id,
            fixture_id=fixture_id,
            client=client,
            limit=limit,
            offset=offset,
        )
    ).parsed



from enum import Enum


class StandingConfigurationsModelStandingBuildingBuildType(str, Enum):
    OVERALL = "OVERALL"
    ROUND = "ROUND"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.season_model_seasonroster_configuration_season_roster_status_allowed_item import (
    SeasonModelSEASONROSTERConfigurationSeasonRosterStatusAllowedItem,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="SeasonModelSEASONROSTERConfiguration")


@_attrs_define
class SeasonModelSEASONROSTERConfiguration:
    """Configuration for the SEASON ROSTER

    Attributes:
        window_open_date (Union[None, Unset, datetime.date]): What date can a SEASON ROSTER be submitted from for this
            SEASON? Example: 2023-01-01.
        window_close_date (Union[None, Unset, datetime.date]): What is the last date a SEASON ROSTER can be submitted
            from for this SEASON? Example: 2023-01-31.
        season_roster_lock (Union[None, Unset, bool]): Make SEASON ROSTERS un-editable when SEASON ROSTER Registration
            Window Close Date has elapsed. Example: True.
        fixture_roster_lock (Union[None, Unset, bool]): Make FIXTURE ROSTERS un-editable when MATCH Status is set to
            Scheduled
        fixture_bib_edit (Union[None, Unset, bool]): Allow Add/Edit of FIXTURE ROSTERS bib
        season_roster_status_allowed (Union[Unset,
            list[SeasonModelSEASONROSTERConfigurationSeasonRosterStatusAllowedItem]]): Season Roster status allowed
        publish_season_roster_roles_in_hours (Union[None, Unset, float]): How long before SEASON starts can rosters or
            roles be published (in hours) Example: True.
        publish_fixture_roster_roles_in_minutes (Union[None, Unset, float]): How long before a MATCH starts can rosters
            or roles be published (in minutes) Example: True.
    """

    window_open_date: Union[None, Unset, datetime.date] = UNSET
    window_close_date: Union[None, Unset, datetime.date] = UNSET
    season_roster_lock: Union[None, Unset, bool] = UNSET
    fixture_roster_lock: Union[None, Unset, bool] = UNSET
    fixture_bib_edit: Union[None, Unset, bool] = UNSET
    season_roster_status_allowed: Union[
        Unset, list[SeasonModelSEASONROSTERConfigurationSeasonRosterStatusAllowedItem]
    ] = UNSET
    publish_season_roster_roles_in_hours: Union[None, Unset, float] = UNSET
    publish_fixture_roster_roles_in_minutes: Union[None, Unset, float] = UNSET

    def to_dict(self) -> dict[str, Any]:
        window_open_date: Union[None, Unset, str]
        if isinstance(self.window_open_date, Unset):
            window_open_date = UNSET
        elif isinstance(self.window_open_date, datetime.date):
            window_open_date = self.window_open_date.isoformat()
        else:
            window_open_date = self.window_open_date

        window_close_date: Union[None, Unset, str]
        if isinstance(self.window_close_date, Unset):
            window_close_date = UNSET
        elif isinstance(self.window_close_date, datetime.date):
            window_close_date = self.window_close_date.isoformat()
        else:
            window_close_date = self.window_close_date

        season_roster_lock: Union[None, Unset, bool]
        if isinstance(self.season_roster_lock, Unset):
            season_roster_lock = UNSET
        else:
            season_roster_lock = self.season_roster_lock

        fixture_roster_lock: Union[None, Unset, bool]
        if isinstance(self.fixture_roster_lock, Unset):
            fixture_roster_lock = UNSET
        else:
            fixture_roster_lock = self.fixture_roster_lock

        fixture_bib_edit: Union[None, Unset, bool]
        if isinstance(self.fixture_bib_edit, Unset):
            fixture_bib_edit = UNSET
        else:
            fixture_bib_edit = self.fixture_bib_edit

        season_roster_status_allowed: Union[Unset, list[str]] = UNSET
        if not isinstance(self.season_roster_status_allowed, Unset):
            season_roster_status_allowed = []
            for season_roster_status_allowed_item_data in self.season_roster_status_allowed:
                season_roster_status_allowed_item = season_roster_status_allowed_item_data.value
                season_roster_status_allowed.append(season_roster_status_allowed_item)

        publish_season_roster_roles_in_hours: Union[None, Unset, float]
        if isinstance(self.publish_season_roster_roles_in_hours, Unset):
            publish_season_roster_roles_in_hours = UNSET
        else:
            publish_season_roster_roles_in_hours = self.publish_season_roster_roles_in_hours

        publish_fixture_roster_roles_in_minutes: Union[None, Unset, float]
        if isinstance(self.publish_fixture_roster_roles_in_minutes, Unset):
            publish_fixture_roster_roles_in_minutes = UNSET
        else:
            publish_fixture_roster_roles_in_minutes = self.publish_fixture_roster_roles_in_minutes

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if window_open_date is not UNSET:
            field_dict["windowOpenDate"] = window_open_date
        if window_close_date is not UNSET:
            field_dict["windowCloseDate"] = window_close_date
        if season_roster_lock is not UNSET:
            field_dict["seasonRosterLock"] = season_roster_lock
        if fixture_roster_lock is not UNSET:
            field_dict["fixtureRosterLock"] = fixture_roster_lock
        if fixture_bib_edit is not UNSET:
            field_dict["fixtureBibEdit"] = fixture_bib_edit
        if season_roster_status_allowed is not UNSET:
            field_dict["seasonRosterStatusAllowed"] = season_roster_status_allowed
        if publish_season_roster_roles_in_hours is not UNSET:
            field_dict["publishSeasonRosterRolesInHours"] = publish_season_roster_roles_in_hours
        if publish_fixture_roster_roles_in_minutes is not UNSET:
            field_dict["publishFixtureRosterRolesInMinutes"] = publish_fixture_roster_roles_in_minutes

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_window_open_date(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                window_open_date_type_0 = isoparse(data).date()

                return window_open_date_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        window_open_date = _parse_window_open_date(d.pop("windowOpenDate", UNSET))

        def _parse_window_close_date(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                window_close_date_type_0 = isoparse(data).date()

                return window_close_date_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        window_close_date = _parse_window_close_date(d.pop("windowCloseDate", UNSET))

        def _parse_season_roster_lock(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        season_roster_lock = _parse_season_roster_lock(d.pop("seasonRosterLock", UNSET))

        def _parse_fixture_roster_lock(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        fixture_roster_lock = _parse_fixture_roster_lock(d.pop("fixtureRosterLock", UNSET))

        def _parse_fixture_bib_edit(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        fixture_bib_edit = _parse_fixture_bib_edit(d.pop("fixtureBibEdit", UNSET))

        season_roster_status_allowed = []
        _season_roster_status_allowed = d.pop("seasonRosterStatusAllowed", UNSET)
        for season_roster_status_allowed_item_data in _season_roster_status_allowed or []:
            season_roster_status_allowed_item = SeasonModelSEASONROSTERConfigurationSeasonRosterStatusAllowedItem(
                season_roster_status_allowed_item_data
            )

            season_roster_status_allowed.append(season_roster_status_allowed_item)

        def _parse_publish_season_roster_roles_in_hours(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        publish_season_roster_roles_in_hours = _parse_publish_season_roster_roles_in_hours(
            d.pop("publishSeasonRosterRolesInHours", UNSET)
        )

        def _parse_publish_fixture_roster_roles_in_minutes(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        publish_fixture_roster_roles_in_minutes = _parse_publish_fixture_roster_roles_in_minutes(
            d.pop("publishFixtureRosterRolesInMinutes", UNSET)
        )

        season_model_seasonroster_configuration = cls(
            window_open_date=window_open_date,
            window_close_date=window_close_date,
            season_roster_lock=season_roster_lock,
            fixture_roster_lock=fixture_roster_lock,
            fixture_bib_edit=fixture_bib_edit,
            season_roster_status_allowed=season_roster_status_allowed,
            publish_season_roster_roles_in_hours=publish_season_roster_roles_in_hours,
            publish_fixture_roster_roles_in_minutes=publish_fixture_roster_roles_in_minutes,
        )

        return season_model_seasonroster_configuration



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.leader_criteria_model_organization import LeaderCriteriaModelOrganization


T = TypeVar("T", bound="LeaderCriteriaModel")


@_attrs_define
class LeaderCriteriaModel:
    """
    Attributes:
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, LeaderCriteriaModelOrganization]): The organization that this LeaderCriteria belongs
            to
        leader_criteria_id (Union[Unset, UUID]): The unique identifier of the leader criteria Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        name (Union[Unset, str]): The name of the criteria
    """

    added: Union[Unset, datetime.datetime] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "LeaderCriteriaModelOrganization"] = UNSET
    leader_criteria_id: Union[Unset, UUID] = UNSET
    name: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        leader_criteria_id: Union[Unset, str] = UNSET
        if not isinstance(self.leader_criteria_id, Unset):
            leader_criteria_id = str(self.leader_criteria_id)

        name = self.name

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if added is not UNSET:
            field_dict["added"] = added
        if updated is not UNSET:
            field_dict["updated"] = updated
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if leader_criteria_id is not UNSET:
            field_dict["leaderCriteriaId"] = leader_criteria_id
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.leader_criteria_model_organization import LeaderCriteriaModelOrganization

        d = dict(src_dict)
        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, LeaderCriteriaModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = LeaderCriteriaModelOrganization.from_dict(_organization)

        _leader_criteria_id = d.pop("leaderCriteriaId", UNSET)
        leader_criteria_id: Union[Unset, UUID]
        if isinstance(_leader_criteria_id, Unset):
            leader_criteria_id = UNSET
        else:
            leader_criteria_id = UUID(_leader_criteria_id)

        name = d.pop("name", UNSET)

        leader_criteria_model = cls(
            added=added,
            updated=updated,
            organization_id=organization_id,
            organization=organization,
            leader_criteria_id=leader_criteria_id,
            name=name,
        )

        return leader_criteria_model
